@@ -441,6 +441,8 @@ while (<INPUT>)
     }
 
     my $string = pack ("U*", @values);
+    $string =~ s/([\x80-\xff])/sprintf "\\x%02x",ord($1)/eg;
+    
     if (1 + length $string > $casefoldlen) {
 	$casefoldlen = 1 + length $string;
     }
@@ -768,7 +770,7 @@ sub print_decomp
     }
     print OUT "\n};\n\n";
 
-    printf OUT "static const char decomp_expansion_string[] = %s;\n\n", $decomp_string;
+    printf OUT "static const guchar decomp_expansion_string[] = %s;\n\n", $decomp_string;
 
     print OUT "#endif /* DECOMP_H */\n";
 
